==> upload-api-client-internal-2.55.0.tgz: package/src/services/JobService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AccountJobId } from "../models/AccountJobId";
import type { AccountJobType } from "../models/AccountJobType";
import type { JobSummary } from "../models/JobSummary";
import type { ListRecentJobsResponse } from "../models/ListRecentJobsResponse";
import { request as __request } from "../core/request";

export class JobService {
  /**
   * Gets information on a job (e.g. a batch file deletion).
   *
   * Requires a `secret_*` API key.
   * @param accountId
   * @param jobId
   * @param jobType
   * @returns JobSummary Success.
   * @throws ApiError
   */
  public static async getJob(accountId: AccountId, jobId: AccountJobId, jobType: AccountJobType): Promise<JobSummary> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/jobs/${jobType}/${jobId}`,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Cancels an in-progress job.
   *
   * Requires a `secret_*` API key.
   * @param accountId
   * @param jobId
   * @param jobType
   * @returns void
   * @throws ApiError
   */
  public static async cancelJob(accountId: AccountId, jobId: AccountJobId, jobType: AccountJobType): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/jobs/${jobType}/${jobId}`,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the most recently issued jobs (e.g. batch file deletions, folder deletions, etc.).
   *
   * Requires a `secret_*` API key.
   * @param accountId
   * @param jobType
   * @returns ListRecentJobsResponse Success.
   * @throws ApiError
   */
  public static async listRecentJobs(
    accountId: AccountId,
    jobType: Array<AccountJobType>
  ): Promise<ListRecentJobsResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/jobs`,
      query: {
        jobType: jobType
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.64.0.tgz: package/src/services/JobService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AccountJobId } from "../models/AccountJobId";
import type { AccountJobType } from "../models/AccountJobType";
import type { JobSummary } from "../models/JobSummary";
import type { ListRecentJobsResponse } from "../models/ListRecentJobsResponse";
import { request as __request } from "../core/request";

export class JobService {
  /**
   * Gets information on a background job.
   *
   * Requires a `secret_*` API key.
   * @param accountId
   * @param jobId
   * @param jobType
   * @returns JobSummary Success.
   * @throws ApiError
   */
  public static async getJob(accountId: AccountId, jobId: AccountJobId, jobType: AccountJobType): Promise<JobSummary> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/jobs/${jobType}/${jobId}`,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Cancels an in-progress background job.
   *
   * Requires a `secret_*` API key.
   * @param accountId
   * @param jobId
   * @param jobType
   * @returns void
   * @throws ApiError
   */
  public static async cancelJob(accountId: AccountId, jobId: AccountJobId, jobType: AccountJobType): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/jobs/${jobType}/${jobId}`,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the most recently issued background jobs.
   *
   * Requires a `secret_*` API key.
   * @param accountId
   * @param jobType
   * @returns ListRecentJobsResponse Success.
   * @throws ApiError
   */
  public static async listRecentJobs(
    accountId: AccountId,
    jobType: Array<AccountJobType>
  ): Promise<ListRecentJobsResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/jobs`,
      query: {
        jobType: jobType
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}
